@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : FileSink.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/FileSink.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -106,7 +106,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: FileSink.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -191,7 +191,7 @@ FileSink :: operator= (  const FileSink &    fs )   throw ( Exception )
 
 
 /*------------------------------------------------------------------------------
- *  Check wether a file exists and is regular file
+ *  Check whether a file exists and is regular file
  *----------------------------------------------------------------------------*/
 bool
 FileSink :: exists ( void ) const               throw ()
@@ -250,7 +250,7 @@ FileSink :: open ( void )                       throw ( Exception )
 
 
 /*------------------------------------------------------------------------------
- *  Check wether the file can be written to
+ *  Check whether the file can be written to
  *----------------------------------------------------------------------------*/
 bool
 FileSink :: canWrite (     unsigned int    sec,
