@@ -337,7 +337,7 @@ VorbisLibEncoder :: write ( const void    * buf,
         int         converted;
 #ifdef HAVE_SRC_LIB
         converterData.input_frames   = nSamples;
-        src_short_to_float_array (shortBuffer, converterData.data_in, totalSamples);
+        src_short_to_float_array (shortBuffer, (float *) converterData.data_in, totalSamples);
         int srcError = src_process (converter, &converterData);
         if (srcError)
              throw Exception (__FILE__, __LINE__, "libsamplerate error: ", src_strerror (srcError));
